@@ -399,6 +399,8 @@ namespace OGLFT {
     //! character; for whom, we've discovered, only the Y position is relevant.
     GLfloat rotation_offset_y_;
 
+    bool do_draw_underline_;
+
     //! Type of the cache of defined glyph to display list mapping.
     typedef std::map< FT_UInt, GLuint > GlyphDLists;
 
@@ -758,6 +760,25 @@ namespace OGLFT {
      */
     virtual double height ( void ) const = 0;
 
+    /*!
+     * \return The position, in font units, of the underline line for this
+     * face. It is the center of the underlining stem.  Only relevant for
+     * scalable formats.
+     */
+    virtual double underline_position ( void ) const = 0;
+
+    /*!
+     * \return The thickness, in font units, of the underline for this face.
+     * Only relevant for scalable formats.
+     */
+    virtual double underline_thickness ( void ) const = 0;
+
+    /*!
+     * This sets whether glyphs are drawn with underline or not. Note that
+     * changing the background color invalidates the glyph cache.
+     */
+    void setDoUnderLine(const bool do_draw_underline);
+
     /*!
      * Compute the bounding box info for a character.
      * \param c the (latin1) character to measure.
@@ -1319,6 +1340,9 @@ namespace OGLFT {
      * \return the height (i.e., line spacing) at the current character size.
      */
     OGLFT_API double height ( void ) const;
+    
+    OGLFT_API double underline_position ( void ) const;
+    OGLFT_API double underline_thickness ( void ) const;
 
     /*!
      * Implement measuring a character in a polygonal face.
@@ -1708,6 +1732,9 @@ namespace OGLFT {
      * \return the height (i.e., line spacing) at the current character size.
      */
     OGLFT_API double height ( void ) const;
+    
+    OGLFT_API double underline_position ( void ) const;
+    OGLFT_API double underline_thickness ( void ) const;
 
     /*!
      * Implement measuring a character in a raster face.
@@ -2056,6 +2083,10 @@ namespace OGLFT {
      */
     OGLFT_API double height ( void ) const;
 
+    OGLFT_API double underline_position ( void ) const;
+    OGLFT_API double underline_thickness ( void ) const;
+    
+
     /*!
      * Implement measuring a character in a texture face.
      * \param c the (latin1) character to measure
