@@ -350,9 +350,12 @@ PsychError IOPORTOpenSerialPort(void)
         "values 'paramValue' to specific serial port parameters 'paramName'. Not all "
         "parameters are supported by all operating systems, and all settings have reasonable "
         "defaults. Settings unknown to a specific operating system are ignored.\n"
+        "Be meticulous when it comes to the spelling in the configuration string, "
+        "as IOPort tends to overlook misspelled parameter names and values silently. "
+        "Especially, do not insert spaces around the equals signs, and pay attention to the case sensitivity.\n"
         "The following is a list of (possibly) supported parameters with their defaults:\n\n"
         "Lenient -- If this keyword is present, then the driver will carry on on certain error conditions "
-        "instead of aborting. This is sometimes neccessary for some special cases like virtual com ports or "
+        "instead of aborting. This is sometimes necessary for some special cases like virtual com ports or "
         "other non-standard setups.\n\n"
         "BaudRate=9600 -- The baud transmission rate of the connection. Standard baud rates include "
         "110, 300, 600, 1200, 2400, 4800, 9600, 14400, 19200, 38400, 57600, 115200, 128000 and "
@@ -369,7 +372,7 @@ PsychError IOPORTOpenSerialPort(void)
         "or on OS/X and Linux in 'Cooked' processing mode as line delimiter. A setting of -1 will try to disable the line terminator.\n\n"
         "DTR=os default    -- Setting for 'Data Terminal Ready' pin: 0 or 1.\n\n"
         "RTS=os default    -- Setting for 'Request To Send' pin: 0 or 1.\n\n"
-        "BreakBehaviour=Ignore -- Behaviour if a 'Break Condition' is detected on the line: Ignore, Flush, Zero. On Windows, this setting is ignored.\n\n"
+        "BreakBehaviour=Ignore -- Behaviour if a 'Break Condition' is detected on the line: Ignore, Flush, Zero. On Windows, only 'Ignore' is allowed.\n\n"
         "OutputBufferSize=4096 -- Size of output buffer in bytes.\n\n"
         "InputBufferSize=4096 -- Size of input buffer in bytes. You can't read more than that amount per read command.\n\n"
         "HardwareBufferSizes=input,output -- Set size of the hardware driver internal input and output buffers in bytes. "
