@@ -91,7 +91,8 @@ static char synopsisString[] =
 "the video engine (e.g., elapsed time since start of capture, or recording time in movie), instead of "
 "the default time base, which is regular GetSecs() time.\n"
 "A setting of 128 will force use of a videorate converter in pure live capture mode. By default the "
-"videorate converter is only used if video recording is active. The converter makes sure that video is "
+"videorate converter is only used if video recording is active, unless flag 8192 is specified. The "
+"converter makes sure that video is "
 "recorded (or delivered) at exactly the requested capture framerate, even if the system isn't really "
 "capable of maintaining that framerate: If the video source (camera) delivers frames at a too low "
 "framerate, the converter will insert duplicated frames to boost up effective framerate. If the source "
@@ -114,7 +115,8 @@ static char synopsisString[] =
 "A setting of 4096 requests to apply some performance optimizations (the setting of filter-caps). This can hurt "
 "if a videocapture device refuses to work, with some error message about ''check your filtered caps, if any.''. "
 "By default, if the flag is omitted, some performance loss will be present, but capture will be more robust "
-"with problematic cameras.\n"
+"with problematic cameras. "
+"A setting of 8192 requests to avoid any use of videorate converters, not even for recording (see above).\n"
 "\n"
 "'captureEngineType' This optional parameter allows selection of the video capture engine to use for this "
 "video source. Allowable values are currently 1 and 3. "
