@@ -17,15 +17,19 @@ function osxsetoctaverpath(mexfname, mexpath)
 % runtime libraries into the mex file folder of PTB, so the mex
 % files should always find a dylib for the currently running Octave.
 
-    if ~IsOSX(1) || ~IsOctave
-        error('osxsetoctaverpath only works with a 64-Bit version of HomeBrew Octave-8.4.0 for macOS!');
+    if ~IsOSX(1) || ~IsOctave || ~compare_versions(version, '9.2.0', '==')
+        error('osxsetoctaverpath only works with a 64-Bit version of HomeBrew Octave-9.2.0 for macOS!');
     end
 
     % If no mex filename given, iterate over 'mexpath' - or the default install
     % location of mex files - and apply the rpath editing to each mex file there:
     if nargin < 1 || isempty(mexfname)
         if nargin < 2 || isempty(mexpath)
-            mexpath = [PsychtoolboxRoot 'PsychBasic/Octave8OSXFiles64/'];
+            if IsARM
+                mexpath = [PsychtoolboxRoot 'PsychBasic/Octave8OSXFilesARM64/'];
+            else
+                mexpath = [PsychtoolboxRoot 'PsychBasic/Octave8OSXFiles64/'];
+            end
         end
 
         d = dir (mexpath);
@@ -51,16 +55,20 @@ function osxsetoctaverpath(mexfname, mexpath)
     % This is how the libdir should be defined automatically:
     libdir = GetOctlibDir;
 
-    % This is sadly how we have to do it with Octave on macOS 13 due to
+    % This is sadly how we have to do it with Octave on macOS 13-14 due to
     % the latest macOS linker crap - Hardcoding the path for a Octave install
     % from HomeBrew. Yes, this is sad...
-    libdir = '/usr/local/opt/octave/lib/octave/8.4.0';
+    if IsARM
+        libdir = '/opt/homebrew/opt/octave/lib/octave/9.2.0';
+    else
+        libdir = '/usr/local/opt/octave/lib/octave/9.2.0';
+    end
 
-    % Replace absolute path to liboctinterp.11.dylib with @rpath:
-    system(['install_name_tool -change ' libdir '/liboctinterp.11.dylib @rpath/liboctinterp.dylib ' mexfname]);
+    % Replace absolute path to liboctinterp.12.dylib with @rpath:
+    system(['install_name_tool -change ' libdir '/liboctinterp.12.dylib @rpath/liboctinterp.dylib ' mexfname]);
 
-    % Replace absolute path to liboctave.10.dylib with @rpath:
-    system(['install_name_tool -change ' libdir '/liboctave.10.dylib @rpath/liboctave.dylib ' mexfname]);
+    % Replace absolute path to liboctave.11.dylib with @rpath:
+    system(['install_name_tool -change ' libdir '/liboctave.11.dylib @rpath/liboctave.dylib ' mexfname]);
 
     % Add one single rpath: @loader_path. This is the path to our folder where our
     % mex file is stored. If we place symlinks to liboctave.dylib and liboctinterp.dylib
