@@ -1,5 +1,22 @@
-function DownloadPsychtoolbox(targetdirectory, flavor, targetRevision, downloadmethod)
-% DownloadPsychtoolbox([targetdirectory][, flavor][, targetRevision][, downloadmethod])
+function DownloadPsychtoolbox(targetdirectory, flavor, targetRevision, downloadmethod, tryNonInteractiveSetup)
+% DownloadPsychtoolbox([targetdirectory][, flavor][, targetRevision][, downloadmethod][, tryNonInteractiveSetup=0])
+%
+% THIS DOWNLOADER DOES NO LONGER WORK, AS GITHUB HAS REMOVED THEIR
+% SUBVERSION FRONTEND, WHICH IT CRITICALLY REQUIRES, FROM THEIR SERVICES
+% PERMANENTLY AT 8TH JANUARY 2024.
+%
+% Due to the lack of financial support for Psychtoolbox by the vast
+% majority of our non-paying users, we did not and currently do not have
+% the funding to work on a good alternative solution for this. Therefore
+% this convenient installation and update method will be unavailable for an
+% unknown period of time.
+%
+% See http://psychtoolbox.org/download.html#alternate-download for a
+% workable, although way less convenient and advanced, download and
+% installation method, via zip file download and execution of
+% SetupPsychtoolbox(). Good luck!
+%
+% =========================================================================
 %
 % This script downloads the latest GNU/Linux, MS-Windows, or Apple macOS
 % Psychtoolbox-3, version 3.0.10 or later, from our git-server to your
@@ -105,6 +122,15 @@ function DownloadPsychtoolbox(targetdirectory, flavor, targetRevision, downloadm
 % SVNKit should not work for some reason.
 %
 %
+% The optional parameter 'tryNonInteractiveSetup' if provided as 1 (true), will
+% try a setup without user interaction, not asking users for input in certain
+% situations, but assuming an answer that keeps the setup progressing. Note that
+% this is not guaranteed to work in all cases, and may end in data loss, e.g.,
+% overwriting an old and potentially user-modified Psychtoolbox installation.
+% This non-interactice setup mode is highly experimental, not well tested, not
+% supported in case of any trouble!
+%
+%
 % INSTALLATION INSTRUCTIONS: The Wiki contains much more up to date
 % instructions. If in doubt, follow instructions on the Wiki!
 %
@@ -346,6 +372,7 @@ function DownloadPsychtoolbox(targetdirectory, flavor, targetRevision, downloadm
 %              on macOS, as provided by XCode command line tools.
 % 06/01/19 mk  Give automated hint about updated svn client under Matlab.
 % 10/27/20 mk  Add SVN support via Matlabs SVNKit.
+% 12/16/23 mk  Add warning about, and handling of GitHub SVN frontend shutdown at 8th January 2024.
 
 % Flush all MEX files: This is needed at least on M$-Windows for SVN to
 % work if Screen et al. are still loaded.
@@ -355,6 +382,31 @@ if nargin < 4 || isempty(downloadmethod)
     downloadmethod = 0;
 end
 
+if nargin < 5 || isempty(tryNonInteractiveSetup)
+    tryNonInteractiveSetup = 0;
+end
+
+% It's the end of the world as we know it...
+fprintf('This Downloader does no longer work, as GitHub has removed their Subversion frontend,\n');
+fprintf('which we critically require, from their services permanently at 8th January 2024.\n\n');
+fprintf('Due to the lack of financial support for Psychtoolbox by the vast majority of our non-paying users,\n');
+fprintf('we did not and currently do not have the funding to work on a good alternative solution for this.\n');
+fprintf('Therefore this convenient installation and update method will be unavailable for an unknown period\n');
+fprintf('of time.\n\n');
+fprintf('See http://psychtoolbox.org/download.html#alternate-download for a workable, although way less\n');
+fprintf('convenient and advanced, download and installation method, via zip file download and execution\n');
+fprintf('of SetupPsychtoolbox(). Good luck!\n\n\n');
+error('Updater aborted due to currently unsupported update method.');
+
+% After date check, leave here commented out as it may be useful in the future...
+%if datenum(date) > datenum('8-Jan-2024') %#ok<*DATE,*DATNM>
+%end
+
+oldpause = pause('query');
+if tryNonInteractiveSetup
+    pause('off');
+end
+
 if (nargin < 2) || isempty(flavor) || isempty(strfind(flavor, 'Psychtoolbox-3.0.'))
     % Check if this is 32-Bit Octave-4 on Windows, which we don't support at all:
     if isempty(strfind(computer, 'x86_64')) && ~isempty(strfind(computer, 'mingw32'))
@@ -482,29 +534,9 @@ switch (flavor)
         fprintf('The "stable" flavor is no longer available.\n');
         error('Flavor "stable" requested. This is no longer available.');
     case 'unsupported'
-        % Very bad choice! Give user a chance to reconsider...
-        fprintf('\n\n\nYou request download of the "unsupported" flavor of Psychtoolbox.\n');
-        fprintf('Use of the "unsupported" flavor is strongly discouraged! It is outdated and contains\n');
-        fprintf('many bugs and deficiencies that have been fixed in the recommended "beta" flavor years ago.\n');
-        fprintf('"unsupported" is no longer maintained and you will not get any support if you have problems with it.\n');
-        fprintf('Please choose "beta" unless you have very good reasons not to do so.\n\n');
-        fprintf('If you answer "no" to the following question, i will download the recommended "beta" flavor instead.\n');
-        answer=input('Do you want to continue download of "unsupported" flavor despite the warnings (yes or no)? ','s');
-        if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
-            flavor = 'beta';
-            fprintf('Download of "unsupported" flavor cancelled, will download recommended "beta" flavor instead...\n');
-        else
-            fprintf('Download of "unsupported" flavor proceeds. You are in for quite a bit of pain...\n');
-        end
-
-        fprintf('\n\nPress any key to continue...\n');
-        pause;
-
-        if ~strcmp(flavor, 'beta')
-            fprintf('\n\n\n\n');
-            fprintf('Psychtoolbox 3.0.10 and later do no longer provide the "unsupported" flavor.\n');
-            error('This Downloader does not support the "unsupported" aka "stable" flavor anymore.');
-        end
+        fprintf('\n\n\n\n');
+        fprintf('Psychtoolbox 3.0.10 and later do no longer provide the "unsupported" flavor.\n');
+        error('This Downloader does not support the "unsupported" aka "stable" flavor anymore.');
 
     otherwise
         fprintf('\n\n\nHmm, requested flavor is the unusual flavor: %s\n',flavor);
@@ -514,7 +546,7 @@ switch (flavor)
         pause;
 end
 
-fprintf('DownloadPsychtoolbox(''%s'',''%s'',''%s'', %i)\n', targetdirectory, flavor, targetRevision, downloadmethod);
+fprintf('DownloadPsychtoolbox(''%s'',''%s'',''%s'', %i, %i)\n', targetdirectory, flavor, targetRevision, downloadmethod, tryNonInteractiveSetup);
 fprintf('Requested flavor is: %s\n', flavor);
 fprintf('Requested location for the Psychtoolbox folder is inside: %s\n', targetdirectory);
 switch (downloadmethod)
@@ -548,7 +580,12 @@ if err
     fprintf(['Once "savepath" works (no error message), run ' mfilename ' again.\n']);
     fprintf('Alternatively you can choose to continue with installation, but then you will have\n');
     fprintf('to resolve this permission isssue later and add the path to the Psychtoolbox manually.\n\n');
-    answer=input('Do you want to continue the installation despite the failure of SAVEPATH (yes or no)? ','s');
+    if ~tryNonInteractiveSetup
+        answer=input('Do you want to continue the installation despite the failure of SAVEPATH (yes or no)? ','s');
+    else
+        answer='no';
+    end
+
     if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
         fprintf('\n\n');
         error('SAVEPATH failed. Please get an administrator to allow everyone to write pathdef.m.');
@@ -572,7 +609,12 @@ else
             '/Users/Shared/ folder, which doesn''t require special privileges. We \n'...
             'recommend installing into the /Applications/ folder, because it''s the \n'...
             'normal place to store programs. \n\n'],targetdirectory);
-            answer=input('Even so, do you want to install the Psychtoolbox into the \n/Users/Shared/ folder (yes or no)? ','s');
+            if tryNonInteractiveSetup
+                answer='yes';
+            else
+                answer=input('Even so, do you want to install the Psychtoolbox into the \n/Users/Shared/ folder (yes or no)? ','s');
+            end
+
             if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
                 fprintf('You didn''t say yes, so I cannot proceed.\n');
                 error('Need administrator privileges for requested installation into folder: %s.',targetdirectory);
@@ -621,7 +663,12 @@ while (exist('Psychtoolbox','dir') || exist(fullfile(targetdirectory,'Psychtoolb
     savepath;
     fprintf('Success.\n');
 
-    answer=input('Shall I delete the old Psychtoolbox folder and all its contents \n(recommended in most cases), (yes or no)? ','s');
+    if tryNonInteractiveSetup
+        answer='yes';
+    else
+        answer=input('Shall I delete the old Psychtoolbox folder and all its contents \n(recommended in most cases), (yes or no)? ','s');
+    end
+
     if strcmpi(answer,'yes') || strcmpi(answer,'y')
         skipdelete = 0;
         fprintf('Now we delete "Psychtoolbox" itself.\n');
@@ -653,7 +700,12 @@ while any(regexp(path,searchpattern))
     fprintf('Your old Psychtoolbox appears in the MATLAB / OCTAVE path:\n');
     paths=regexp(path,['[^' pathsep ']*' pathsep],'match');
     fprintf('Your old Psychtoolbox appears %d times in the MATLAB / OCTAVE path.\n',length(paths));
-    answer=input('Before you decide to delete the paths, do you want to see them (yes or no)? ','s');
+    if tryNonInteractiveSetup
+        answer='no';
+    else
+        answer=input('Before you decide to delete the paths, do you want to see them (yes or no)? ','s');
+    end
+
     if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
         fprintf('You didn''t say "yes", so I''m taking it as no.\n');
     else
@@ -664,7 +716,13 @@ while any(regexp(path,searchpattern))
             end
         end
     end
-    answer = input('Shall I delete all those instances from the MATLAB / OCTAVE path (yes or no)? ', 's');
+
+    if tryNonInteractiveSetup
+        answer='yes';
+    else
+        answer = input('Shall I delete all those instances from the MATLAB / OCTAVE path (yes or no)? ', 's');
+    end
+
     if ~strcmpi(answer, 'yes') && ~strcmpi(answer, 'y')
         fprintf('You didn''t say yes, so I cannot proceed.\n');
         fprintf('Please use the MATLAB "File:Set Path" command to remove all instances of "Psychtoolbox" from the path.\n');
@@ -674,6 +732,10 @@ while any(regexp(path,searchpattern))
         s = char(p);
         if any(regexp(s, searchpattern2))
             % fprintf('rmpath(''%s'')\n',s);
+            if strcmpi(s, pwd)
+                % Octave 6.4+: rmpath can not remove current working directory from path, so switch it:
+                cd('..');
+            end
             rmpath(s);
         end
     end
@@ -757,6 +819,8 @@ if exist('PsychtoolboxPostInstallRoutine.m', 'file')
    PsychtoolboxPostInstallRoutine(0, flavor);
 end
 
+pause(oldpause);
+
 % Puuh, we are done :)
 return
 
