@@ -34,9 +34,6 @@ alGetString(alGetError)
 
 % Try to load some impressive sound...
 sounddir = [PsychtoolboxRoot 'PsychDemos/SoundFiles/'];
-%sounddir = '/Library/Application Support/GarageBand/Instrument Library/Sampler/Sampler Files/String Ensemble/';
-%sounddir = '/Library/Application Support/GarageBand/Instrument Library/Sampler/Sampler Files/Grand Piano/';
-
 soundfiles = dir([sounddir '*.wav']);
 
 % Velocity of listener: Walks straight down the z-axis:
@@ -158,8 +155,8 @@ end
 alSourceStopv(length(sources), sources);
 
 for i=1:nsources
-    % Unqueue sound buffer:
-    alSourceUnqueueBuffers(sources(i), 1, buffers(i));
+    % Remove sound buffer:
+    alSourcei(sources(i), AL.BUFFER, 0);
 end
 
 % Wait a bit:
