@@ -276,9 +276,9 @@ try
     end;
     Priority(0);
     ShowCursor
-    Screen('CloseAll');
+    sca;
 catch
     Priority(0);
     ShowCursor
-    Screen('CloseAll');
+    sca;
 end
