@@ -185,12 +185,12 @@ try
     end;
 
     Priority(0);
-    Screen('CloseAll');
+    sca;
 
 catch
     %this "catch" section executes in case of an error in the "try" section
     %above. Importantly, it closes the onscreen window if its open.
-    Screen('CloseAll');
+    sca;
     Priority(0);
     psychrethrow(psychlasterror);
 end %try..catch..
