@@ -158,7 +158,7 @@ try
     % On ARM set the default pixelFormat to 6 for shader based decode.
     % On a RaspberryPi-4 this makes a world of difference when playing
     % HD movies, between slow-motion 2 fps and proper 24 fps playback.
-    if isempty(pixelFormat) && IsARM
+    if isempty(pixelFormat) && IsARM && IsLinux
         pixelFormat = 6;
     end
 
