@@ -2,16 +2,17 @@ function resultFlag = IsOSX(is64)
 
 % resultFlag = IsOSX([is64=0])
 %
-% Returns true if the operating system is Mac OS X.
+% Returns true if the operating system is macOS.
 % If the optional 'is64' flag is set to one, returns
-% true if the runtime is 64 bit and on OSX.
+% true if the runtime is 64 bit and on macOS.
 %
 % See also: IsWin, IsLinux, OSName, computer
 
 % HISTORY
-% ??/??/?? awi Wrote it.
-% 6/30/06  awi Fixed help section.
-% 4/30/12  mk  Support 64-Bit OS/X.
+% ??/??/??  awi Wrote it.
+% 06/30/06  awi Fixed help section.
+% 04/30/12  mk  Support 64-Bit OS/X.
+% 12/16/23  mk  Simplify.
 
 persistent rc;
 persistent rc64;
@@ -21,13 +22,12 @@ if nargin < 1 || isempty(is64)
      is64 = 0;
 end
 
-
 if isempty(rc)
-     rc = streq(computer,'MAC') || streq(computer, 'MACI') || streq(computer, 'MACI64') || ~isempty(strfind(computer, 'apple-darwin'));
+     rc = ismac;
 end
 
 if isempty(rc64)
-     rc64 = rc && ~isempty(strfind(computer, '64'));
+     rc64 = rc && Is64Bit;
 end
 
 if is64 == 0
