@@ -72,12 +72,17 @@ function oldClut = LoadIdentityClut(windowPtr, loadOnNextFlip, lutType, disableD
 %                identity lut via LoadNormalizedGammaTable before using low-level
 %                identity lut setup, which can only deal with discrete lut's, not
 %                pwl lut's or such.
-% 07/10/17   MR  Added gfxhwtype=5 for AMD graphics cards under Windows (see also 
+% 07/10/17   mr  Added gfxhwtype=5 for AMD graphics cards under Windows (see also 
 %                the new variable 'ditherApiVer').
 % 06/13/19   mk  Use gfxhwtype=0 on modern AMD DCE-10+ / DCN gpu's in the Linux
 %                fallback path. It's the right choice for Linux 5.3+ with DC, and
 %                especially crucial on DCN APUs if we really want to do without
 %                dedicated low-level setup code for these new GPU gen's.
+% 02/22/23   mr  Revert to always using gfxhwtype=0 for AMD graphics cards under  
+%                Windows (instead of gfxhwtype=5 if GPUCoreId=='R600' and 
+%                ditherApiVer==2 - see 07/10/17). This is because, meanwhile, 
+%                AMD has fixed the gfxhwtype=0 issues in their drivers, now making 
+%                gfxhwtype=5 a bad choice.
 
 global ptb_original_gfx_cluts;
 
@@ -316,16 +321,8 @@ else
                     % At least the Radeon HD 3470 under Windows Vista and Linux needs type 0
                     % LUT's. Let's assume for the moment this is true for all R600
                     % cores, ie., all Radeon HD series cards.
-                    % gfxhwtype==0 does not work for newer drivers. Since the driver version seems 
-                    % to be less indicative for the change, we base our decision on the dither API 
-                    % version implemented by AMD's display library (ADL). 
-                    if ditherApiVer==2
-                        fprintf('LoadIdentityClut: ATI Radeon HD-2000 or later with dither API v2 detected. Using type-5 LUT.\n');
-                        gfxhwtype = 5;
-                    else
-                        fprintf('LoadIdentityClut: ATI Radeon HD-2000 or later detected. Using type-0 LUT.\n');
-                        gfxhwtype = 0;
-                    end
+                    fprintf('LoadIdentityClut: ATI Radeon HD-2000 or later detected. Using type-0 LUT.\n');
+                    gfxhwtype = 0;
                 elseif IsLinux
                     % AMD GPU with DCE 10+ display engine or with a DCN display engine?
                     % If so, this will use AMD DisplayCore by default and starting with Linux 4.17
