@@ -46,10 +46,18 @@ end
 
 if nargin < 3 || isempty(primitivetype)
     primitivetype = 0;
+else
+    if ~ismember(primitivetype, [0, 1, 2, 3, 4])
+        error('Unsupported primitivetype specified. Must be 0 - 4.');
+    end
 end
 
 if nargin < 4 || isempty(mode)
     mode = 0;
+else
+    if ~ismember(mode, [0, 1, 2, 3])
+        error('Unsupported mode specified. Must be 0 - 3.');
+    end
 end
 
 if nargin < 5 || isempty(gpumeasure)
@@ -61,7 +69,7 @@ AssertOpenGL;
 
 % Open window with gray background on secondary display (if any):
 screenid = max(Screen('Screens'));
-[win winrect] = Screen('OpenWindow', screenid, 128, [], [], [], [], 0);
+[win, winrect] = Screen('OpenWindow', screenid, 128, [], [], [], [], 0);
 
 % Setup stim parameters:
 w=RectWidth(winrect);
@@ -84,15 +92,15 @@ if mode == 2 || mode == 3
     % Draw prototype primitive which covers the full window and has a color
     % and alpha value of 255 ie. white and fully opaque:
     switch primitivetype
-        case 0,
+        case 0
             Screen('FillRect', template, 255);
-        case 1,
+        case 1
             Screen('FrameRect', template, 255, [0 0 msize msize], 50);
-        case 2,
+        case 2
             Screen('FillOval', template, 255);
-        case 3,
+        case 3
             Screen('FrameOval', template, 255);
-        case 4,
+        case 4
             Screen('FillArc', template, 255, [], 45, 180);
     end
 end
@@ -102,7 +110,7 @@ end
 for j = 1:n
     posx = rand * w;
     posy = rand * h;
-    colors(j, 1:3) = [ rand * 255, rand * 255, rand * 255];
+    colors(j, 1:3) = [ rand * 255, rand * 255, rand * 255]; %#ok<*AGROW> 
     myrect(j, 1:4) = floor([ posx, posy, posx + rand * sizeX, posy + rand * sizeY]);
     sizes(j) = floor(rand * 10)+1;
 end
@@ -128,7 +136,7 @@ for i=1:1000
     % Batch draw:
     if mode < 2
         switch primitivetype
-            case 0,
+            case 0
                 if mode == 1
                     % Batch drawing version of FillRect - submit all
                     % primitives at once:
@@ -141,7 +149,7 @@ for i=1:1000
                         Screen('FillRect', win, colors(:,j)', myrect(:,j)');
                     end
                 end
-            case 1,
+            case 1
                 if mode == 1
                     Screen('FrameRect', win, colors, myrect, sizes);
                 end
@@ -152,7 +160,7 @@ for i=1:1000
                     end
                 end
 
-            case 2,
+            case 2
                 if mode == 1
                     Screen('FillOval', win, colors, myrect);
                 end
@@ -162,7 +170,7 @@ for i=1:1000
                         Screen('FillOval', win, colors(:,j)', myrect(:,j)');
                     end
                 end
-            case 3,
+            case 3
                 if mode == 1
                     Screen('FrameOval', win, colors, myrect, sizes);
                 end
@@ -173,7 +181,7 @@ for i=1:1000
                     end
                 end
 
-            case 4,
+            case 4
                 % No batch drawing for FillArc:
                 if mode == 0 || mode == 1
                     for j=1:n
@@ -187,7 +195,7 @@ for i=1:1000
             for j=1:n
                 % DrawTexture in a loop:
                 Screen('DrawTexture', win, template, [], myrect(:,j)', [], 0, [], colors(:,j)');
-            end;
+            end
         else
             % Batch drawing version DrawTextures:
             Screen('DrawTextures', win, template, [], myrect, 0, 0, 0, colors);
