@@ -1,5 +1,5 @@
-function PsychPortAudioDataPixxTimingTest(waitTime, exactstart, deviceid, latbias, triggerLevel)
-% PsychPortAudioDataPixxTimingTest([waitTime = 1][, exactstart=1][, deviceid=-1][, latbias=0][, triggerLevel=0.01])
+function PsychPortAudioDataPixxTimingTest(waitTime, exactstart, deviceid, latbias, triggerLevel, reqlatencyclass)
+% PsychPortAudioDataPixxTimingTest([waitTime = 1][, exactstart=1][, deviceid=-1][, latbias=0][, triggerLevel=0.01][, reqlatencyclass=2])
 %
 % Test script for sound onset timing reliability and sound onset latency of
 % the PsychPortAudio sound driver.
@@ -40,11 +40,19 @@ function PsychPortAudioDataPixxTimingTest(waitTime, exactstart, deviceid, latbia
 %                  calibration. This will likely need tweaking on your
 %                  setup.
 %
+% 'reqlatencyclass' Override setting for reqlatencyclass parameter. By default,
+%                   reqlatencyclass = 2 is used, for exclusive device access for
+%                   low latency / high timing precision mode.
 
 nTrials = 10;
 
-% Initialize driver, request low-latency preinit:
-InitializePsychSound(1);
+if nargin < 6 || isempty(reqlatencyclass)
+    % Request latency mode 2, a tad more aggressive than the default:
+    reqlatencyclass = 2;
+end
+
+% Initialize driver, request low-latency preinit for reqlatencyclass > 1:
+InitializePsychSound(double(reqlatencyclass > 1));
 
 % Force GetSecs and WaitSecs into memory to avoid latency later on:
 GetSecs; WaitSecs(0.1);
@@ -113,9 +121,6 @@ else
     disp(devs(idx));
 end
 
-% Request latency mode 2:
-reqlatencyclass = 2;
-
 % Requested output frequency, may need adaptation on some audio-hw:
 freq = 44100;       % Must set this. 44.1 khz most likely to work, as shown by experience. Common rates: 96khz, 48khz, 44.1khz.
 buffersize = 0;     % Pointless to set this. Auto-selected to be optimal.
